#include <cstdio>

#define MAXM 200000
#define MAXK 10000

const long long L = ((long long)1) << 32;

struct point
{
	long long x, y, z;
	point() : x(0), y(0), z(0)
	{
	}
	void operator=(const point& a)
	{
		x=a.x; y=a.y; z=a.z;
	}
	void operator-=(const point& a)
	{
		x-=a.x; y-=a.y; z-=a.z;
	}
	void operator+=(const point& a)
	{
		x+=a.x; y+=a.y; z+=a.z;
	}
	void operator*=(int k)
	{
		x*=k; y*=k; z*=k;
	}
	void operator/=(int k)
	{
		x/=k; y/=k; z/=k;
	}
	bool operator==(const point& a)
	{
		return (x==a.x && y==a.y && z==a.z);
	}
};

const point& norm(const point& a, const point& b, const point& c)
{
	static point u,v,r;
	u = b; u -= a;
	v = c; v -= a;
	r.x = u.y*v.z-u.z*v.y;
	r.y = u.z*v.x-u.x*v.z;
	r.z = u.x*v.y-u.y*v.x;
	return r;
}

void mul(long long a, long long b, long long& r2, long long& r1, long long& r0)
{
	long long a1 = a/L, a0 = a%L;
	long long b1 = b/L, b0 = b%L;
	long long p0 = a0*b0, p1 = (a1*b0+a0*b1), p2=a1*b1;
	r2 = p2 + p1/L;
	r1 = p1%L + p0/L;
	r0 = p0%L;
}

inline int sign2(long long a, long long b, long long c, long long d, long long e, long long f)
{
	long long p0,p1,p2,q0,q1,q2,r0,r1,r2,z0,z1,z2;
	bool sa=(a<0), sb=(b<0), sc=(c<0), sd=(d<0), se=(e<0), sf=(f<0), sp=sa^sb, sq=sc^sd, sr=se^sf;
  if (sa) a=-a;
  if (sb) b=-b;
  if (sc) c=-c;
  if (sd) d=-d;
  if (se) e=-e;
  if (sf) f=-f;
	mul(a,b,p2,p1,p0);
	mul(c,d,q2,q1,q0);
	mul(e,f,r2,r1,r0);
	if (sp) p2=-p2, p1=-p1, p0=-p0;
	if (sq) q2=-q2, q1=-q1, q0=-q0;
	if (sr) r2=-r2, r1=-r1, r0=-r0;
	z2 = p2+q2+r2;
	z1 = p1+q1+r1;
	z0 = p0+q0+r0;
	while (z0<0) z0+=L, z1--;
	z1 += z0/L; z0 %= L;
	while (z1<0) z1+=L, z2--;
	z2 += z1/L; z1 %= L;
	return (z2>0 ? 1 : z2<0 ? -1 : z1>0 ? 1 : z1<0 ? -1 : z0>0 ? 1 : z0<0 ? -1 : 0);
}

inline int sign(long long a)
{
	return (a>0 ? 1 : a<0 ? -1 : 0);
}

bool same(const point& p, const point& n, const point& a, const point& b)
{
	static point u,v;
	u = a; u -= p;
	v = b; v -= p;
	return (sign(u.x*n.x+u.y*n.y+u.z*n.z) * sign(v.x*n.x+v.y*n.y+v.z*n.z)) >= 0;
}

point P[MAXK], R[2][MAXK];
point W[MAXM], V[MAXM];
point U[MAXM][3];
point N[MAXM];
point O, A;
int   K[MAXM];
bool  found;

int main()
{
	int D;
	scanf("%d",&D);
	for (int d=0; d<D; d++)
	{
		int M;
		scanf("%d %d",&M,&K[0]);
		for (int k=0; k<K[0]; k++)
		{
			scanf("%lld %lld %lld",&P[k].x,&P[k].y,&P[k].z);
			R[0][k] = P[k];
			if (k<3)
				U[0][k] = P[k];
		}
		W[0] = P[0];
		for (int m=1; m<M; m++)
		{
			scanf("%d",&K[m]);
		  found = false;
			for (int k=0; k<K[m]; k++)
			{
			  scanf("%lld %lld %lld",&R[m%2][k].x,&R[m%2][k].y,&R[m%2][k].z);
				if (k<3)
					U[m][k] = R[m%2][k];
        if (!found)
				{
					bool id = false;
				  for (int j=0; j<K[m-1]; j++)
						if (R[m%2][k]==R[(m+1)%2][j])
						{
							id = true;
							break;
						}
					if (!id)
					{
						V[m-1] = R[m%2][k];
						found = true;
					}
				}
			}
			W[m] = R[m%2][0];
		}
		found = false;
		for (int k=0; k<K[0]; k++)
			if (!found)
  		{
			  bool id = false;
				for (int j=0; j<K[M-1]; j++)
					if (P[k]==R[(M+1)%2][j])
					{
						id = true;
						break;
					}
				if (!id)
				{
					V[M-1] = P[k];
					found = true;
				}
	  	}
		for (int m=0; m<M; m++)
			N[m] = norm(U[m][0],U[m][1],U[m][2]);
		int n;
		scanf("%d",&n);
		for (int i=0; i<n; i++)
		{
			scanf("%lld %lld %lld",&A.x,&A.y,&A.z);
			bool ok = true;
			for (int m=0; m<M; m++)
				if (!same(W[m],N[m],V[m],A))
				{
					ok = false;
					break;
				}
			if (ok)
				printf("TAK\n");
			else
				printf("NIE\n");
		}
		printf("\n");
	}
}

